@@ -18,7 +18,7 @@ log = logging.getLogger()
 log.setLevel(logging.INFO)
 
 class CrossValidation(BaseExperiment):
-    r"""Performs stratified K-fold cross validation.
+    """Performs stratified K-fold cross validation.
 
     Attributes:
 
@@ -325,7 +325,7 @@ class CrossValidation(BaseExperiment):
         Returns:
 
             tuple: The best model structure and its information.
-            
+
         """
         self.fit_or_cv = "CV"
         self.update_log_path()
