@@ -162,7 +162,10 @@ class _MLP(nn.Module):
 
 
 class MLP(BaseNet):
-    """Multi-layer perceptron with identical # of hidden units.
+    """Multi-layer perceptron with identical number of hidden units for each layer.
+
+    The number of hidden units for each layer should be specified in `n_hidden_units` and the number of layers should
+    be specified in `n_layers`.
 
     Args:
 
@@ -450,7 +453,7 @@ class _ContractingMLP(nn.Module):
         return self.layers(X)
 
 class ContractingMLP(BaseNet):
-    """ContractingMLP
+    """Multi-Layer perceptron with number of hidden units for each layer contracting with `contraction_ratio`.
         
     Args:
     
@@ -540,17 +543,17 @@ class ContractingMLP(BaseNet):
 
 
 class _CustomMLP(nn.Module):
-    """
-    _CustomMLP and CustomMLP defines an MLP with number of hidden units for hidden layers 
+    """Mutli-layer perceptron with specified hidden units for each hidden layer as a list.
+
+    CustomMLP defines an MLP with number of hidden units for hidden layers 
     customized for all layers. 
 
     We can define n_hidden_units for all hidden layers with a list of integers.
 
     The hyperparameters that are only in CustomMLP are 'layer_{n}_dim's (for all hidden layers). 
 
-
-    _CustomMLP and CustomMLP are basically identical in structure. The only difference is that
-    _CustomMLP is an offspring of nn.Module and CustomMLP is an offspring of BaseNet.
+    Example::
+        >>> 
 
     Args:
         
@@ -593,7 +596,7 @@ class _CustomMLP(nn.Module):
         scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         activation_type : str = "relu",
         negative_slope : Optional[float] = 0.2,
-        n_hidden_units_list : Optional[List[int]] = None,
+        n_hidden_units_list : Optional[List[int]] = [],
         momentum : float=0.9,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
     ) -> None:
@@ -625,7 +628,7 @@ class _CustomMLP(nn.Module):
         
         layers = []
 
-        if self.n_hidden_units_list is None:
+        if self.n_hidden_units_list is None or self.n_hidden_units_list == []:
             if self.n_classes is None:
                 layers.append(nn.Linear(self.dims, 1))
             elif self.n_classes > 2:
@@ -685,6 +688,46 @@ class _CustomMLP(nn.Module):
         return self.layers(X)
 
 class CustomMLP(BaseNet):
+    """Mutli-layer perceptron with specified hidden units for each hidden layer as a list.
+
+    CustomMLP defines an MLP with number of hidden units for hidden layers 
+    customized for all layers. 
+
+    We can define n_hidden_units for all hidden layers with a list of integers.
+
+    The hyperparameters that are only in CustomMLP are 'layer_{n}_dim's (for all hidden layers). 
+
+    Example::
+
+        >>> model = CustomMLP(dims=(1,8,8), n_classes=10, n_hidden_units_list=[30,20,10])
+
+    Args:
+        
+        dims (Union[int, Tuple[int]]): The dimension of the data. e.g., 4, (1,8,8)
+
+        n_classes (Optional[int]) : Number of classes (labels) in the classification task.
+        
+        n_hidden_units_list : Optional[List[int]] : List of all n_hidden_units for all hidden layers.
+                                                    If not specified, it would be a single-layer perceptron.
+
+        batch_size (int) : Batch size. Default : 64 (see utils_lightning.py)
+
+        optimizer_type (str) : Type of the optimizer. ("adam" or "sgd") 
+            Default : ``"adam"`` 
+
+        dropout_p (float) : Dropout probability 
+            Default : ``0`` 
+
+        bn (bool) : Whether to use batch normalization or not. 
+            Default : ``True`` 
+
+        weight_decay (float) : coefficient for L2-regularization. 
+            Default : ``0`` 
+
+        lr (float) : Learning rate. 
+            Default: ``1e-4`` 
+
+    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -692,7 +735,7 @@ class CustomMLP(BaseNet):
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
         scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams : Any
-    ) -> None:
+    )->None:
         
         entire_keys = [
             'dims', 
@@ -710,7 +753,7 @@ class CustomMLP(BaseNet):
             'momentum'
             ]
         default_parameter_dict = {
-            'n_hidden_units_list' : None
+            'n_hidden_units_list' : []
         }
         
         # set default for model-specific hyperparameters
@@ -720,13 +763,13 @@ class CustomMLP(BaseNet):
         #set default for model-agnostic hyperparameters
         set_default_parameters(hparams)
         # add hparams : layer_n_dim
-        for idx in range(1, len(self.n_hidden_units_list)+1):
+        for idx in range(1, len(hparams['n_hidden_units_list'])+1):
             key_str = 'layer_' + str(idx) +'_dim'
-            hparams.update({key_str : self.n_hidden_units_list[idx-1]}) 
+            hparams.update({key_str : hparams['n_hidden_units_list'][idx-1]}) 
         # save information of **hparams to self.hparams.
         self.save_hyperparameters(*hparams)
         # n_hidden_units_list
-        for n_hidden_units in self.n_hidden_units_list:
+        for n_hidden_units in hparams['n_hidden_units_list']:
             if n_hidden_units <=0:
                 raise ValueError(f"Number of hidden units can't be less than or equal to 0.")
 
